==> CodeMirror-0.1.3.zip: CodeMirror/lang/ext/fr_FR.php <==
<?php
$lang['friendlyname'] = 'Editeur de syntaxe color&eacute; CodeMirror';
$lang['postinstall'] = 'Le module CodeMirror a &eacute;t&eacute; install&eacute; avec succ&egrave;s';
$lang['needpermission'] = '&#039;Vous avez besoin de l&#039;autorisation &#039;%s&#039;  pour cette fonction';
$lang['settingstab'] = 'Param&egrave;tres';
$lang['savesettings'] = 'Sauvegarder les param&egrave;tres';
$lang['settingssaved'] = 'Param&egrave;tres sauvegard&eacute;s';
$lang['htmltest'] = 'Test de syntaxe HTML ';
$lang['csstest'] = 'Test de syntaxe CSS ';
$lang['phptest'] = 'Test de syntaxe PHP';
$lang['showlinenumbers'] = 'Afficher le nombre de lignes';
$lang['help'] = '<strong>Que fait ce module&nbsp;?</strong>
<br/>
Le module CodeMirror vous permet de modifier le contenu, les gabarits et les feuilles de style en utilisant un &eacute;diteur de syntaxe color&eacute; l&#039;int&eacute;rieur de votre navigateur. 
Il peut aussi bien remplacer l&#039;&eacute;diteur WYSIWYG, et permettre de visualiser-&eacute;diter les gabarits, feuilles de style. (Uniquement pour version CMSMS 1.1 ou plus)
<br/><br/>
<strong>Comment l&#039;utiliser&nbsp;?</strong><br/>
Il vous suffit de l&#039;installer, et dans &quot;Mes pr&eacute;f&eacute;rences / Pr&eacute;f&eacute;rences de l&#039;utilisateur&quot; choisir avec le menu d&eacute;roulant CodeMirror dans &quot;S&eacute;lectionner la syntaxe surlign&eacute;e&quot; et/ou &eacute;ventuellement dans &quot;S&eacute;lection du WYSIWYG &agrave; utiliser&quot;.
';
$lang['utma'] = '156861353.2008046241.1243954976.1243954976.1243954976.1';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1243954976.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
?>

==> CodeMirror-0.1.5.zip: CodeMirror/lang/ext/fr_FR.php <==
<?php
$lang['friendlyname'] = 'Editeur de syntaxe color&eacute; CodeMirror';
$lang['postinstall'] = 'Le module CodeMirror a &eacute;t&eacute; install&eacute; avec succ&egrave;s';
$lang['needpermission'] = '&#039;Vous avez besoin de l&#039;autorisation &#039;%s&#039;  pour cette fonction';
$lang['settingstab'] = 'Param&egrave;tres';
$lang['savesettings'] = 'Sauvegarder les param&egrave;tres';
$lang['settingssaved'] = 'Param&egrave;tres sauvegard&eacute;s';
$lang['htmltest'] = 'Test de syntaxe HTML ';
$lang['csstest'] = 'Test de syntaxe CSS ';
$lang['phptest'] = 'Test de syntaxe PHP';
$lang['examplesyntax'] = 'Syntaxe pour tester avec&nbsp;';
$lang['change'] = 'Changer ...';
$lang['showlinenumbers'] = 'Afficher le nombre de lignes';
$lang['textwrapping'] = 'Retour &agrave; la ligne automatique';
$lang['help'] = '<strong>Que fait ce module&nbsp;?</strong>
<br/>
Le module CodeMirror vous permet de modifier le contenu, les gabarits et les feuilles de style en utilisant un &eacute;diteur de syntaxe color&eacute; l&#039;int&eacute;rieur de votre navigateur. 
Il peut aussi bien remplacer l&#039;&eacute;diteur WYSIWYG, et permettre de visualiser-&eacute;diter les gabarits, feuilles de style. (Uniquement pour version CMSMS 1.1 ou plus)
<br/><br/>
<strong>Comment l&#039;utiliser&nbsp;?</strong><br/>
Il vous suffit de l&#039;installer, et dans &quot;Mes pr&eacute;f&eacute;rences / Pr&eacute;f&eacute;rences de l&#039;utilisateur&quot; choisir avec le menu d&eacute;roulant CodeMirror dans &quot;S&eacute;lectionner la syntaxe surlign&eacute;e&quot; et/ou &eacute;ventuellement dans &quot;S&eacute;lection du WYSIWYG &agrave; utiliser&quot;.
';
$lang['utmz'] = '156861353.1262713546.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['qca'] = 'P0-1624099198-1262715852421';
$lang['utma'] = '156861353.167550954.1264667874.1264667874.1264679216.2';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
